Discover Packages
github.com/MrAzharuddin/employee-crud/employee-service
pkg
rest
server
models
package
Version:
v0.0.0-...-e19a3a7
Opens a new window with list of versions in this module.
Published: May 9, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Employee struct {
gorm .Model
Name string `json:"name,omitempty"`
Position string `json:"position,omitempty"`
Salary float64 `json:"salary,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.